@@ -17,12 +17,11 @@
 #include "mainwindow.h"
 #include "preferences.h"
 #include "resourcescalendar.h"
-#include "resources/resourcedatamodelbase.h"
-#include "resources/resourcecreator.h"
 #include "resources/datamodel.h"
-#include "resources/resources.h"
+#include "resources/resourcecreator.h"
+#include "resources/resourcedatamodelbase.h"
 #include "resources/resourcemodel.h"
-#include "lib/autoqpointer.h"
+#include "resources/resources.h"
 #include "lib/messagebox.h"
 #include "lib/packedlayout.h"
 #include "kalarm_debug.h"
@@ -229,14 +228,14 @@ void ResourceSelector::removeResource()
                                   : CalEvent::EMPTY;
     if (stdType == CalEvent::ACTIVE)
     {
-        KAMessageBox::sorry(this, i18nc("@info", "You cannot remove your default active alarm calendar."));
+        KAMessageBox::error(this, i18nc("@info", "You cannot remove your default active alarm calendar."));
         return;
     }
     if (stdType == CalEvent::ARCHIVED  &&  Preferences::archivedKeepDays())
     {
         // Only allow the archived alarms standard resource to be removed if
         // we're not saving archived alarms.
-        KAMessageBox::sorry(this, i18nc("@info", "You cannot remove your default archived alarm calendar "
+        KAMessageBox::error(this, i18nc("@info", "You cannot remove your default archived alarm calendar "
                                         "while expired alarms are configured to be kept."));
         return;
     }
